@@ -11,6 +11,8 @@ from .constants import (
     Command,
     Constant,
     Register,
+    SpinCommand,
+    SpinValue,
     Status,
 )
 from .utility import (
@@ -58,6 +60,8 @@ class SpinDevice:
         buffer = [0] * self._total_devices
         buffer[self._position] = byte_value
 
+        print(buffer)
+
         response = self._spi.xfer2(buffer)
 
         return response[self._position]
@@ -96,7 +100,8 @@ class SpinDevice:
         :value: Value register should be set to
         """
         _value = SpinValue(value, Register.getSize(register))
-        set_command = (Command.ParamSet | register).setPayload(_value)
+        set_command = Command.ParamSet | register
+        set_command.setPayload(_value)
 
         return self._writeCommand(set_command)
 
@@ -108,9 +113,19 @@ class SpinDevice:
 
         """
         RegisterSize = Register.getSize(register)
+        print(f'Wat: {Command.ParamGet} | {register}')
+        print(f'Command val should be {Command.ParamGet | register}')
         self._writeCommand(Command.ParamGet | register)
 
-        response_bytes = self._write(SpinValue([Command.Nop] * RegisterSize))
+        response_bytes: List[int] = []
+
+        print('Kwokka')
+        for _ in range(RegisterSize):
+            response_bytes += self._write(Command.Nop)
+            print(f'Growing: {response_bytes}')
+
+        print('Kwokka DONE')
+
         return SpinValue(response_bytes)
 
     def move(self, steps: int) -> None:
@@ -122,7 +137,8 @@ class SpinDevice:
         assert(steps >= 0)
         assert(steps <= Constant.MaxSteps)
 
-        command = (Command.Move | self._direction).setPayload(steps)
+        command = (Command.Move | self._direction)
+        command.setPayload(steps)
         self._writeCommand(command)
 
     def run(self, steps_per_second: float) -> None:
@@ -136,11 +152,12 @@ class SpinDevice:
         assert(steps_per_second <= Constant.MaxStepsPerSecond)
 
         speed = int(steps_per_second * Constant.SpsToSpeed)
-        command = (Command.Run | self._direction).setPayload(speed)
+        command = (Command.Run | self._direction)
+        command.setPayload(speed)
 
         self._writeCommand(command)
 
-    def setDirection(self, direction: int) -> None:
+    def setDirection(self, direction: SpinValue) -> None:
         """Set motor direction. Does not affect active movement
 
         :direction: Direction as declared in Constant
@@ -195,4 +212,4 @@ class SpinDevice:
         # So as not to clear any warning flags
         status = self.getRegister(Register.Status)
 
-        return False if (status & Status.NotBusy) else True
+        return False if (status.Value & Status.NotBusy) else True
